"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// note that we are using @heroku-cli/command instead of @oclif/command
// this inherits from @oclif/command but extends it with Heroku-specific functionality
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const debug = require("debug");
const tatara_1 = require("../../tatara");
const child = require('child_process');
class Build extends command_1.Command {
    async run() {
        const { flags } = this.parse(Build);
        let bin = (new tatara_1.Tatara(process.platform).path());
        let cmdArgs = ['build', process.cwd(), flags.app];
        if (flags['skip-stack-pull']) {
            cmdArgs.push('--skip-stack-pull');
        }
        let envVars;
        if (flags.config) {
            let envVars = await this.heroku.get(`/apps/${flags.app}/config-vars`);
            for (var name in envVars.body) {
                let value = envVars.body[name];
                cmdArgs.push(`--env=${name}=${value}`);
            }
        }
        if (debug('local:build').enabled) {
            cmdArgs.push(`--debug`);
        }
        cli_ux_1.cli.debug(`Executing ${bin}`);
        let spawned = child.spawn(bin, cmdArgs, { stdio: 'pipe' })
            .on('error', (err) => {
            cli_ux_1.cli.debug(err);
            this.error(`Failed to build ${flags.app}`);
        })
            .on('close', (code) => {
            if (code)
                this.error(`Failed to build ${flags.app}`);
        });
        spawned.stdout.on('data', (chunk) => {
            process.stdout.write(chunk.toString());
        });
        spawned.stderr.on('data', (chunk) => {
            process.stderr.write(chunk.toString());
        });
    }
}
Build.description = 'Build an app locally';
Build.examples = [`
$ heroku local:build`,
];
Build.flags = {
    remote: command_1.flags.remote(),
    app: command_1.flags.app({ required: true }),
    'skip-stack-pull': command_1.flags.boolean(),
    config: command_1.flags.boolean()
};
exports.default = Build;
