"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// note that we are using @heroku-cli/command instead of @oclif/command
// this inherits from @oclif/command but extends it with Heroku-specific functionality
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const tatara_1 = require("../../tatara");
const child = require('child_process');
class Export extends command_1.Command {
    async run() {
        const { flags } = this.parse(Export);
        let bin = (new tatara_1.Tatara(process.platform)).path();
        let cmdArgs = ['export', flags.app];
        if (flags.tag) {
            cmdArgs.push('--tag');
            cmdArgs.push(flags.tag);
        }
        if (flags['skip-stack-pull']) {
            cmdArgs.push('--skip-stack-pull');
        }
        cli_ux_1.cli.debug(`Executing ${bin}`);
        let spawned = child.spawn(bin, cmdArgs, { stdio: 'pipe' })
            .on('error', (err) => {
            cli_ux_1.cli.log(err);
            this.error(err);
        })
            .on('close', (code) => {
            if (code)
                this.error(code);
        });
        spawned.stdout.on('data', (chunk) => {
            process.stdout.write(chunk.toString());
        });
        spawned.stderr.on('data', (chunk) => {
            process.stderr.write(chunk.toString());
        });
    }
}
Export.description = 'Export a build to a Docker image';
Export.examples = [`
$ heroku local:export`,
];
Export.flags = {
    remote: command_1.flags.remote(),
    app: command_1.flags.app({ required: true }),
    tag: command_1.flags.string({ description: 'the tag for the Docker image' }),
    'skip-stack-pull': command_1.flags.boolean()
};
exports.default = Export;
