"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// note that we are using @heroku-cli/command instead of @oclif/command
// this inherits from @oclif/command but extends it with Heroku-specific functionality
const command_1 = require("@heroku-cli/command");
const cli_ux_1 = require("cli-ux");
const debug = require("debug");
const tatara_1 = require("../../tatara");
const child = require('child_process');
class Run extends command_1.Command {
    async run() {
        const { flags } = this.parse(Run);
        let bin = (new tatara_1.Tatara(process.platform)).path();
        let cmdArgs = ['run', flags.app];
        if (flags['skip-stack-pull']) {
            cmdArgs.push('--skip-stack-pull');
        }
        if (debug('local:run').enabled) {
            cmdArgs.push(`--debug`);
        }
        let envVars;
        if (flags.config) {
            let envVars = await this.heroku.get(`/apps/${flags.app}/config-vars`);
            for (var name in envVars.body) {
                let value = envVars.body[name];
                cmdArgs.push(`--env=${name}=${value}`);
            }
        }
        let spawned = child.spawn(bin, cmdArgs, { stdio: 'pipe' })
            .on('error', (err) => {
            cli_ux_1.cli.log(err);
            this.error(err);
        })
            .on('close', (code) => {
            if (code)
                this.error(code);
        });
        spawned.stdout.on('data', (chunk) => {
            process.stdout.write(chunk.toString());
        });
        spawned.stderr.on('data', (chunk) => {
            process.stderr.write(chunk.toString());
        });
    }
}
Run.description = 'Run a locally built app';
Run.examples = [`
$ heroku local:run`,
];
Run.flags = {
    remote: command_1.flags.remote(),
    app: command_1.flags.app({ required: true }),
    'skip-stack-pull': command_1.flags.boolean(),
    config: command_1.flags.boolean()
};
exports.default = Run;
